pub enum DomainValue {
Form(DomainForm),
List(Vec<DomainValue>),
String(String),
Atom(String),
}Expand description
A parsed domain-form value.
Variants
Form(DomainForm)
A nested #(...) form.
List(Vec<DomainValue>)
A [...] list.
String(String)
A "..." string.
Atom(String)
A bare atom (number, identifier, 4/4, …).
Implementations
Sourceimpl DomainValue
impl DomainValue
Sourcepub fn as_form(&self) -> Result<&DomainForm, DomainFormError>
pub fn as_form(&self) -> Result<&DomainForm, DomainFormError>
The nested form, if this value is a #(...) form.
Errors with WrongValueKind for a
list, string, or atom.
Sourcepub fn atom_or_string(&self) -> Result<&str, DomainFormError>
pub fn atom_or_string(&self) -> Result<&str, DomainFormError>
The text of this value when it is a bare atom or a quoted string.
Errors with WrongValueKind for a
list or nested form.
Sourcepub fn render_text(&self) -> String
pub fn render_text(&self) -> String
Renders this value back to its ASCII #(...) source text: an atom to
its literal text, a string to its escaped quoted form, a list to
[a,b,...], and a nested form via format_domain_form.
Round-trips through parse_domain_form for a top-level form value.