pub fn codec_value(codec: CodecRuntime) -> ValueExpand description
Wrap a CodecRuntime as an opaque runtime Value for registry storage.
pub fn codec_value(codec: CodecRuntime) -> ValueWrap a CodecRuntime as an opaque runtime Value for registry storage.