encode_value_with_codec

Function encode_value_with_codec 

pub fn encode_value_with_codec(
    cx: &mut Cx,
    symbol: &Symbol,
    value: &Value,
    options: EncodeOptions,
) -> Result<Output>
Encode a runtime Value with the codec named symbol, forcing lists and tables into an Expr via encode_value_expr before encoding.