pub struct RuntimeCodecPrism { /* private fields */ }Expand description
Runtime-backed CodecPrism for an installed codec symbol.
Implementations
Sourceimpl RuntimeCodecPrism
impl RuntimeCodecPrism
Sourcepub fn domain(codec: Symbol, domain: impl Into<String>) -> Self
pub fn domain(codec: Symbol, domain: impl Into<String>) -> Self
Builds a fail-closed prism for a domain codec.
Sourcepub fn binary_base64(codec: Symbol) -> Self
pub fn binary_base64(codec: Symbol) -> Self
Builds a prism for the base64 text wrapper around binary frames.
Sourcepub fn parse_bytes(&self, cx: &mut Cx, bytes: &[u8]) -> PrismParse
pub fn parse_bytes(&self, cx: &mut Cx, bytes: &[u8]) -> PrismParse
Parses raw bytes. Text codecs receive UTF-8 validation from the codec runtime; binary codecs inspect the bytes as untrusted frame data.
Sourcepub fn round_trip_bytes(
&self,
cx: &mut Cx,
bytes: &[u8],
position: EncodePosition,
) -> RoundTrip
pub fn round_trip_bytes( &self, cx: &mut Cx, bytes: &[u8], position: EncodePosition, ) -> RoundTrip
Parses, encodes, and reparses raw bytes to prove semantic identity.